@@ -17,7 +17,7 @@
 #
 
 """Various utility classes."""
-from __future__ import print_function, unicode_literals
+
 
 import base64
 from collections import deque
@@ -290,7 +290,7 @@ class VByteBuffer(object):
         """Overloads the len() operator to return number of bytes in buffer."""
         # This seems to be required for 64-bit systems
         length = self._length
-        if isinstance(length, long):
+        if isinstance(length, int):
             length = int(length)
         return length
 
@@ -499,7 +499,7 @@ class VStatus(VCondition):
                 return (isinstance(status, int)
                         and 0 <= status < cls._num_states)
         VStatusWithStates._num_states = len(states)
-        for i in xrange(len(states)):
+        for i in range(len(states)):
             if hasattr(VStatusWithStates, states[i]):
                 raise ValueError('Illegal state name', state[i])
             setattr(VStatusWithStates, states[i], i)
@@ -1012,7 +1012,7 @@ class VSimpleBus(VLockable):
         """
         with self:
             _ids = set()
-            for key, val in self._listeners.items():
+            for key, val in list(self._listeners.items()):
                 _listener = val()
                 if _listener is None or _listener is listener:
                     _ids.add(key)
@@ -1038,7 +1038,7 @@ class VSimpleBus(VLockable):
         """
         with self:
             _discard_ids = set()
-            for _id, _w_listener in self._listeners.items():
+            for _id, _w_listener in list(self._listeners.items()):
                 _listener = _w_listener()
                 if _listener is None:
                     _discard_ids.add(_id)
@@ -1207,7 +1207,7 @@ class VBitfield(object):
             bits_a = diff*(0,) + bits_a
         else:
             bits_b = diff*(0,) + bits_b
-        result_bits = tuple(a | b for a, b in zip(bits_a, bits_b))
+        result_bits = tuple(a | b for a, b in list(zip(bits_a, bits_b)))
         return VBitfield(result_bits)
 
     def __and__(self, other):
@@ -1232,7 +1232,7 @@ class VBitfield(object):
             bits_a = diff*(0,) + bits_a
         else:
             bits_b = diff*(0,) + bits_b
-        result_bits = tuple(a & b for a, b in zip(bits_a, bits_b))
+        result_bits = tuple(a & b for a, b in list(zip(bits_a, bits_b)))
         return VBitfield(result_bits)
 
     def truth(self):
@@ -1272,7 +1272,7 @@ class VConfig(dict):
         super(VConfig, self).__init__()
         super(VConfig, self).__setattr__('_cblock', threading.RLock())
         super(VConfig, self).__setattr__('_callback', dict())
-        for key, value in kargs.items():
+        for key, value in list(kargs.items()):
             self[key] = value
 
     def copy(self, deep=True):
@@ -1296,7 +1296,7 @@ class VConfig(dict):
             d = self
         else:
             d = dict()
-            for key, val in self.items():
+            for key, val in list(self.items()):
                 if isinstance(val, VConfig):
                     d[key] = val.copy(deep=True)
                 else:
@@ -1364,7 +1364,7 @@ class VConfig(dict):
     def __callback(self, name, value):
         with self._cblock:
             dead = set()
-            for wref, method in self._callback.items():
+            for wref, method in list(self._callback.items()):
                 o = wref()
                 if not o:
                     dead.add(wref)
@@ -1538,14 +1538,14 @@ def posint_to_bytes(number):
     if _pyver == 2:
         if offset:
             data.append(_s2b(_b_chr(int(hex_str[2], 16))))
-        for i in xrange(num_bytes - offset):
+        for i in range(num_bytes - offset):
             pos = 2 + 2*i + offset
             data.append(_s2b(_b_chr(int(hex_str[pos:(pos+2)], 16))))
         return b''.join(data)
     else:
         if offset:
             data.append(int(hex_str[2], 16))
-        for i in xrange(num_bytes - offset):
+        for i in range(num_bytes - offset):
             pos = 2 + 2*i + offset
             data.append(int(hex_str[pos:(pos+2)], 16))
         return bytes(data)
@@ -1562,7 +1562,7 @@ def posint_to_netbytes(number):
     specifications.
 
     """
-    if not isinstance(number, (int, long)) or number < 0:
+    if not isinstance(number, int) or number < 0:
         raise TypeError('Number must be a non-negative integer')
 
     if number <= 246:
@@ -1599,7 +1599,7 @@ def signedint_to_bytes(number):
     * Encodes negative integers as (2*abs(number) + 1).
 
     """
-    if not isinstance(number, (int, long)):
+    if not isinstance(number, int):
         raise TypeError('Number must be an integer')
     if number >= 0:
         return posint_to_bytes(2*number)
@@ -1624,7 +1624,7 @@ def signedint_to_netbytes(number):
         same 'unsigned' or 'signed' version that it was encoded with.
 
     """
-    if not isinstance(number, (int, long)):
+    if not isinstance(number, int):
         raise TypeError('Number must be an integer')
 
     if number >= 0:
