@@ -32,7 +32,7 @@ adaptation of Bruce Schneier's `C implementation
 <http://www.schneier.com/blowfish-download.html>`__\ .
 
 """
-from __future__ import print_function, unicode_literals
+
 
 import copy
 
@@ -67,9 +67,9 @@ class Blowfish(object):
 
         keylen = len(key)
         j = 0
-        for i in xrange(len(P)):
+        for i in range(len(P)):
             data = 0
-            for k in xrange(4):
+            for k in range(4):
                 data = ((data << 8) & 0xffffffff) | _b_ord(key[j])
                 j += 1
                 if j >= keylen:
@@ -77,15 +77,15 @@ class Blowfish(object):
             P[i] ^= data
 
         data = 8*b'\x00'
-        for i in xrange(0, len(P), 2):
+        for i in range(0, len(P), 2):
             data = self.encipher(data)
             P[i] = ((_b_ord(data[0]) << 24) + (_b_ord(data[1]) << 16) +
                     (_b_ord(data[2]) << 8 ) + _b_ord(data[3]))
             P[i+1] = ((_b_ord(data[4]) << 24) + (_b_ord(data[5]) << 16) +
                       (_b_ord(data[6]) << 8 ) + _b_ord(data[7]))
 
-        for i in xrange(4):
-            for j in xrange(0, 256, 2):
+        for i in range(4):
+            for j in range(0, 256, 2):
                 data = self.encipher(data)
                 S[i][j] = ((_b_ord(data[0]) << 24) + (_b_ord(data[1]) << 16) +
                            (_b_ord(data[2]) << 8 ) + _b_ord(data[3]))
@@ -150,7 +150,7 @@ class Blowfish(object):
                (_b_ord(block[6]) << 8 ) + _b_ord(block[7]))
         P, S = self.__P, self.__S
 
-        for i in xrange(16):
+        for i in range(16):
             b_l ^= P[i]
             b_r ^= self.__feistel(b_l)
             b_l, b_r = b_r, b_l
@@ -200,7 +200,7 @@ class Blowfish(object):
                (_b_ord(block[6]) << 8 ) + _b_ord(block[7]))
         P, S = self.__P, self.__S
 
-        for i in xrange(17, 1, -1):
+        for i in range(17, 1, -1):
             b_l ^= P[i]
             b_r ^= self.__feistel(b_l)
             b_l, b_r = b_r, b_l
