@@ -17,7 +17,7 @@
 #
 
 """Crypto provider using crypto functions from 3rd party library PyCrypto."""
-from __future__ import print_function, unicode_literals
+
 
 from Crypto.Hash import SHA
 from Crypto.Cipher import Blowfish, AES
@@ -387,7 +387,7 @@ class _PyRSANumTransform(VNumTransform):
     def __init__(self, keydata, encrypt):
         def _convert(num):
             if num is not None:
-                return long(num)
+                return int(num)
             else:
                 return None
         self.__keydata = [_convert(item) for item in keydata]
@@ -411,8 +411,8 @@ class _PyRSANumTransform(VNumTransform):
 
     def transform(self, num):
         if isinstance(num, int):
-            num = long(num)
-        elif not isinstance(num, long):
+            num = int(num)
+        elif not isinstance(num, int):
             raise VCryptoException('Transformed number must be int or long')
         return self.__transform(num)
 
@@ -532,7 +532,7 @@ class _PyRSAKey(VAsymmetricKey):
             raise VCryptoException('RSA key data must be 5-tuple')
         for item in keydata:
             if not (item is None or
-                    isinstance(item, (int, long)) and item >= 0):
+                    isinstance(item, int) and item >= 0):
                 raise VCryptoException('Invalid key data')
         n, e, d, p, q = keydata
         if n is None:
