@@ -17,7 +17,7 @@
 #
 
 """Implementats the :term:`VOB` specification."""
-from __future__ import print_function, unicode_literals
+
 
 import inspect
 import textwrap
@@ -61,7 +61,7 @@ def meta_as(name):
                 pass
 
     """
-    if not isinstance(name, unicode):
+    if not isinstance(name, str):
         raise TypeError('@meta_as() name argument must be unicode')
     def decor(f):
         f.meta = True
@@ -104,7 +104,7 @@ def doc(c):
     except:
         raise TypeError('was unable to normalize docstring indentation')
     try:
-        doc = unicode(doc)
+        doc = str(doc)
     except:
         raise TypeError('@doc docstring could not be converted to unicode')
     c._v_external_doc = doc
@@ -123,7 +123,7 @@ def doc_with(doc):
             \"\"\"This is an internal docstring\"\"\"
 
     """
-    if not isinstance(doc, unicode):
+    if not isinstance(doc, str):
         raise TypeError('@doc_as docstring must be unicode')
     def decor(c):
         if not issubclass(c, VExternal):
@@ -132,7 +132,7 @@ def doc_with(doc):
         return c
     return decor
 
-def publish(name=None, doc=False, show=False, ctx=False):
+def publish(name=None, doc=False, show=False, ctx=True):
     """Decorator for publishing a :class:`VExternal` method externally.
 
     Keyword arguments:
@@ -154,11 +154,11 @@ def publish(name=None, doc=False, show=False, ctx=False):
     Example use::
 
         class MyClass(VExternal):
-            @publish(name=u'my_method_a', show=True, doc=True)
+            @publish(name=u'my_method_a', show=True, doc=True, ctx=False)
             def a_method(self, arg1, arg2):
                 \"\"\"This doc string will be published\"\"\"
                 pass
-            @publish(ctx=True)
+            @publish()
             def my_method_b(self, arg1, arg2, ctx=None):
                 pass
 
@@ -173,7 +173,7 @@ def publish(name=None, doc=False, show=False, ctx=False):
         else:
             f.external_name = None
 
-        if isinstance(_doc, unicode):
+        if isinstance(_doc, str):
             f.external_doc = _doc
         elif isinstance(_doc, bool):
             if _doc:
@@ -200,7 +200,7 @@ def publish(name=None, doc=False, show=False, ctx=False):
                         except:
                             raise TypeError('unable to normalize docstring')
                         try:
-                            doc = unicode(doc)
+                            doc = str(doc)
                         except Exception:
                             raise TypeError('cannot convert doc to unicode')
                         else:
@@ -290,14 +290,14 @@ class VExternal(VObject):
 
                 name = method.external_name
                 if name is None:
-                    name = unicode(method.__name__)
+                    name = str(method.__name__)
                 self.__methods[name] = method_data
                 self.__method_names[method_func] = name
 
             if hasattr(method, 'meta') and method.meta:
                 name = method.meta_name
                 if name is None:
-                    name = unicode(method.__name__)
+                    name = str(method.__name__)
                 method_func, instance_method = self._v_unwind_method(method)
                 meta_data = _VMetaData(method_func, instance_method)
                 self.__meta[name] = meta_data
@@ -323,7 +323,7 @@ class VExternal(VObject):
             m_name, args = args[0], args[1:]
         else:
             regular_call = True
-        if m_name is None or not isinstance(m_name, (unicode, VString)):
+        if m_name is None or not isinstance(m_name, (str, VString)):
             raise VCallError('Missing or invalid method name parameter')
 
         if regular_call:
@@ -356,7 +356,7 @@ class VExternal(VObject):
             else:
                 raise VCallError('Not a provided meta method')
 
-    def _v_publish(self, method, name=None, doc=False, ctx=False, show=False):
+    def _v_publish(self, method, name=None, doc=False, ctx=True, show=False):
         """Publishes a method, making it externally callable.
 
         :param method: the method to publish
@@ -370,11 +370,11 @@ class VExternal(VObject):
         """
         with self.__methods_lock:
             if name is None:
-                name = unicode(method.__name__)
+                name = str(method.__name__)
             if name in self.__methods:
                 raise VEntityError('Another method published with same name')
             method_func, instance_method = self._v_unwind_method(method)
-            if isinstance(doc, unicode):
+            if isinstance(doc, str):
                 doc = _doc
             elif isinstance(doc, bool):
                 if doc:
@@ -384,7 +384,7 @@ class VExternal(VObject):
                         doc = None
                     else:
                         try:
-                            doc = unicode(doc)
+                            doc = str(doc)
                         except Exception:
                             raise TypeError('cannot convert doc to unicode')
                         else:
@@ -408,7 +408,7 @@ class VExternal(VObject):
 
         """
         with self.__methods_lock:
-            name = self.__method_names.pop(method.im_func, None)
+            name = self.__method_names.pop(method.__func__, None)
             if name is not None:
                 self.__methods.pop(name, None)
 
@@ -439,7 +439,7 @@ class VExternal(VObject):
                     return doc
             elif len(args) == 1:
                 method_name = args[0]
-                if not isinstance(method_name, (unicode, VString)):
+                if not isinstance(method_name, (str, VString)):
                     raise VCallError('Method argument must be a VString')
                 method_data = self.__methods.get(method_name, None)
                 if method_data:
@@ -453,7 +453,7 @@ class VExternal(VObject):
     def _v_methods(self, **kargs):
         with self.__methods_lock:
             result = []
-            for name, method_data in self.__methods.items():
+            for name, method_data in list(self.__methods.items()):
                 if method_data.show:
                     result.append(name)
             result.sort()
@@ -470,13 +470,13 @@ class VExternal(VObject):
         """
         if not inspect.ismethod(method):
             raise RuntimeError('Not a method')
-        if method.im_self is self:
+        if method.__self__ is self:
             is_instance_call = True
-        elif method.im_self is self.__class__:
+        elif method.__self__ is self.__class__:
             is_instance_call = False
         else:
             raise RuntimeError('Not instance or class method of this object')
-        return method.im_func, is_instance_call
+        return method.__func__, is_instance_call
 
 
 class _VMethodData:
