@@ -17,7 +17,7 @@
 #
 
 """Framework for the :term:`VOL` specification for links."""
-from __future__ import print_function, unicode_literals
+
 
 import collections
 from threading import Lock
@@ -867,8 +867,8 @@ class VLink(VObjectIOContext):
         if not isinstance(msg_data, VTuple) or len(msg_data) != 2:
             raise VLinkError('Malformed VLink protocol deref message')
         peer_id, peer_recv_count = msg_data
-        if (not isinstance(peer_id, (int, long, VInteger))
-            or not isinstance(peer_recv_count, (int, long, VInteger))):
+        if (not isinstance(peer_id, (int, VInteger))
+            or not isinstance(peer_recv_count, (int, VInteger))):
             raise VLinkError('Malformed VLink protocol deref message')
         peer_id = peer_id._v_native()
         peer_recv_count = peer_recv_count._v_native()
@@ -1421,7 +1421,7 @@ class VHandshake(VObject, VCondition):
         # Validate input argument
         if isinstance(keep_alive_t, VInteger):
             keep_alive_t = keep_alive_t._v_native()
-        if not isinstance(keep_alive_t, (int, long)) or keep_alive_t <= 0:
+        if not isinstance(keep_alive_t, int) or keep_alive_t <= 0:
             raise VCallError()
 
         link = self._wlink()
@@ -1484,7 +1484,7 @@ class VHandshake(VObject, VCondition):
             granted_t = self._peer._v_call('keep_alive', req_t)
             if isinstance(granted_t, VInteger):
                 granted_t = granted_t._v_native()
-            if not isinstance(granted_t, (int, long)) or granted_t < req_t:
+            if not isinstance(granted_t, int) or granted_t < req_t:
                 raise VException('Invalid negotiated keep-alive from peer')
             link._keep_alive_recv = granted_t
 
@@ -1576,7 +1576,7 @@ class VLinkReference(VReference):
         """
         nowait = nores = oneway = False
         checks = None
-        for key, val in kargs.items():
+        for key, val in list(kargs.items()):
             if key == 'nowait':
                 nowait = bool(val)
             elif key == 'nores':
