@@ -17,7 +17,7 @@
 #
 
 """Module framework for resolving :term:`VER` encoded entities."""
-from __future__ import print_function, unicode_literals
+
 
 from threading import Lock
 
@@ -96,7 +96,7 @@ class VModuleResolver(VTaggedParser):
             if not tags:
                 raise VTaggedParseUnknown('No tags set on object')
             encoding, etags = VEntity._v_lazy_native(tags[0]), tags[1:]
-            if not isinstance(encoding, (int, long) or encoding < -1):
+            if not isinstance(encoding, (int, int) or encoding < -1):
                 raise VTaggedParseUnknown()
             if encoding == -1:
                 if len(etags) < 2:
@@ -119,7 +119,7 @@ class VModuleResolver(VTaggedParser):
                 oid_tags, mod_tags = etags[:oid_enc_len], etags[oid_enc_len:]
                 oid_tags = VEntity._v_lazy_native(oid_tags)
                 for t in oid_tags:
-                    if not isinstance(t, (int, long)) or t < 0:
+                    if not isinstance(t, int) or t < 0:
                         raise VTaggedParseError()
             else:
                 return VTaggedParseUnknown()
@@ -251,7 +251,7 @@ class VModuleResolver(VTaggedParser):
         """
         with cls._imported_modules_lock:
             if VModuleResolver._enable_vse_modules != status:
-                for mod in cls._imported_vse_modules.values():
+                for mod in list(cls._imported_vse_modules.values()):
                     if status:
                         cls._imported_modules.add(mod)
                     else:
