@@ -18,7 +18,7 @@
 
 """Framework for setting up :term:`VOL` listening services."""
 
-from __future__ import print_function, unicode_literals
+
 
 import copy
 import socket
@@ -501,7 +501,7 @@ class VServiceController(VExternal):
         self._max_clients = max_clients
         self._max_node_clients = max_node_clients
 
-    @publish(show=True, doc=True)
+    @publish(show=True, doc=True, ctx=False)
     def accepted(self, node):
         """Callback from a node informing it accepted a client connection.
 
@@ -521,7 +521,7 @@ class VServiceController(VExternal):
                 self._approved.discard(node)
             self.__process()
 
-    @publish(show=True, doc=True)
+    @publish(show=True, doc=True, ctx=False)
     def closed(self, node):
         """Callback from a node informing a client connection was closed.
 
@@ -596,7 +596,7 @@ class VServiceController(VExternal):
             if not self._nodes or self._approved:
                 return frozenset()
             d = dict()
-            for h, num in self._nodes.items():
+            for h, num in list(self._nodes.items()):
                 d[num] = h
             min_num = min(d.keys())
             h = d[min_num]
@@ -610,7 +610,7 @@ class VServiceController(VExternal):
                 _mc, _mnc = self._max_clients, self._max_node_clients
                 available_node = False
                 tot_clients = 0
-                for num in self._nodes.values():
+                for num in list(self._nodes.values()):
                     if _mnc is None or num < _mnc:
                         available_node = True
                     tot_clients += num
@@ -649,7 +649,7 @@ class VServiceNode(VExternal):
         self._service = None
         self._cntl = None
 
-    @publish(show=True, doc=True)
+    @publish(show=True, doc=True, ctx=False)
     def start_service(self, cntl):
         """Registers a controller and starts the node's service.
 
@@ -667,7 +667,7 @@ class VServiceNode(VExternal):
             self._cntl = cntl
             self._service.start()
 
-    @publish(show=True, doc=True)
+    @publish(show=True, doc=True, ctx=False)
     def stop_service(self, stop_links, force):
         """Requests the node's service to stop.
 
@@ -682,7 +682,7 @@ class VServiceNode(VExternal):
             self._service = None
             self._cntl = None
 
-    @publish(show=True, doc=True)
+    @publish(show=True, doc=True, ctx=False)
     def can_accept(self):
         """Authorizes the node's service to accept a single client connection.
 
