@@ -17,7 +17,7 @@
 #
 
 """Reactor based implementation of the :mod:`versile.orb.link` framework."""
-from __future__ import print_function, unicode_literals
+
 
 import threading
 import time
@@ -456,7 +456,7 @@ class VLinkAgent(VLink, VEntityWAgent):
             # Pass exception to all local calls waiting for a result
             self._ref_calls_lock.acquire()
             try:
-                calls = self._ref_calls.values()
+                calls = list(self._ref_calls.values())
                 self._ref_calls.clear()
             finally:
                 self._ref_calls_lock.release()
