@@ -17,7 +17,7 @@
 #
 
 """Reactor components for :term:`TLS` socket I/O."""
-from __future__ import print_function, unicode_literals
+
 
 import errno
 import socket
@@ -75,19 +75,19 @@ class VTLSClientBase(object):
                  tls_cafile, tls_req_cert, tls_p_auth=None):
         self._tls_wrapped = tls_wrapped
         self._tls_server = tls_server
-        if tls_keyfile and not isinstance(tls_keyfile, (bytes, unicode)):
+        if tls_keyfile and not isinstance(tls_keyfile, (bytes, str)):
             self._tls_keyfile = tls_keyfile
             self._tls_keyfile_name = tls_keyfile.name
         else:
             self._tls_keyfile = None
             self._tls_keyfile_name = tls_keyfile
-        if tls_certfile and not isinstance(tls_certfile, (bytes, unicode)):
+        if tls_certfile and not isinstance(tls_certfile, (bytes, str)):
             self._tls_certfile = tls_certfile
             self._tls_certfile_name = tls_certfile.name
         else:
             self._tls_certfile = None
             self._tls_certfile_name = tls_certfile
-        if tls_cafile and not isinstance(tls_cafile, (bytes, unicode)):
+        if tls_cafile and not isinstance(tls_cafile, (bytes, str)):
             self._tls_cafile = tls_cafile
             self._tls_cafile_name = tls_cafile.name
         else:
