@@ -17,7 +17,7 @@
 #
 
 """Versile UDP Transport, a reliable UDP transport."""
-from __future__ import print_function, unicode_literals
+
 
 from collections import deque
 import errno
@@ -291,7 +291,7 @@ class VUDPTransport():
         """See :meth:`versile.reactor.io.IVByteHandleInput.do_read`\ ."""
 
         # Read limited datagrams to enable reactor to regain control
-        for _iter in xrange(_MAX_DGRAM/MAX_DATA):
+        for _iter in range(_MAX_DGRAM/MAX_DATA):
             if self._sock_closed:
                 self.stop_reading()
                 break
@@ -545,7 +545,7 @@ class VUDPTransport():
                     if self._rbuf_spos + len(self._rbuf) > close_pos:
                         self.__fail('close flag conflicts with other data')
                         return
-                    for _pos, _data in self._recv_queue.items():
+                    for _pos, _data in list(self._recv_queue.items()):
                         if _pos + len(_data) > close_pos:
                             self.__fail('close flag conflicts with other data')
                             return
@@ -833,7 +833,7 @@ class VUDPTransport():
 
         if self._in_fl:
             # Resend all expired in-flight packages
-            for pos, in_fl_pkg in self._in_fl.items():
+            for pos, in_fl_pkg in list(self._in_fl.items()):
                 _f_t_stamp, _f_delay = in_fl_pkg[1], in_fl_pkg[2]
                 resend_t = _f_t_stamp + min(_f_delay, self._rto)
                 if resend_t <= cur_time:
@@ -848,7 +848,7 @@ class VUDPTransport():
 
             # Reset the RTO timer
             _future = deque()
-            for in_fl_pkg in self._in_fl.values():
+            for in_fl_pkg in list(self._in_fl.values()):
                 _f_t_stamp, _f_delay = in_fl_pkg[1], in_fl_pkg[2]
                 _future.append(_f_t_stamp + min(_f_delay, self._rto))
             self._set_rto_timer(min(_future)-cur_time)
@@ -1436,23 +1436,23 @@ class VUDPRelayedVOPConnecter(VExternal):
                     _handler._cancel()
         self._peer_gw = Result(self)
 
-    @publish(show=True)
+    @publish(show=True, ctx=False)
     def confirm_udp(self, host, port):
         if self._num_confirm_calls != 0:
             raise VException('May only call confirm_udp once')
         self._num_confirm_calls += 1
-        vchk(host, vtyp(unicode), vset)
-        vchk(port, vtyp(int, long), 1024<=port<=65535)
+        vchk(host, vtyp(str), vset)
+        vchk(port, vtyp(int, int), 1024<=port<=65535)
         # This will stop UDP handshake re-transmission
         self._external_udp = (host, port)
 
-    @publish(show=True)
+    @publish(show=True, ctx=False)
     def link_to_peer(self, host, port, l_sec, r_sec):
         if self._num_link_calls != 0:
             raise VException('May only call link_to_peer once')
         self._num_link_calls += 1
-        vchk(host, vtyp(unicode), vset)
-        vchk(port, vtyp(int, long), 1024<=port<=65535)
+        vchk(host, vtyp(str), vset)
+        vchk(port, vtyp(int, int), 1024<=port<=65535)
         vchk(l_sec, vtyp(bytes), len(l_sec)<=32)
         vchk(r_sec, vtyp(bytes), len(r_sec)<=32)
         link = VLinkAgent(gateway=self._gateway, reactor=self._reactor,
@@ -1621,7 +1621,7 @@ class VUDPRelayedVOPApprover(VExternal):
         self._udp_filter = udp_filter
         self._rand = VUrandom()
 
-    @publish(show=True)
+    @publish(show=True, ctx=False)
     def approve(self, path, host, port, r_token, client_ip,
                 client_key, client_certs):
         """Remote method called by link to initiate UDP based service.
@@ -1651,18 +1651,18 @@ class VUDPRelayedVOPApprover(VExternal):
         """
         vchk(path, vtyp(tuple), vset)
         for item in path:
-            vchk(item, vtyp(unicode), vset)
-        vchk(host, vtyp(unicode), vset)
-        vchk(port, vtyp(int, long), 1024<=port<=65535)
+            vchk(item, vtyp(str), vset)
+        vchk(host, vtyp(str), vset)
+        vchk(port, vtyp(int, int), 1024<=port<=65535)
         vchk(r_token, vtyp(bytes), len(r_token)<=32)
         if client_ip is not None:
-            vchk(client_ip, vtyp(unicode))
+            vchk(client_ip, vtyp(str))
         if client_key is not None:
-            vchk(client_key, vtyp(unicode))
+            vchk(client_key, vtyp(str))
         if client_certs is not None:
             vchk(client_certs, vtyp(tuple), len(client_certs)>0)
             for _cert in client_certs:
-                vchk(_cert, vtyp(unicode), vset)
+                vchk(_cert, vtyp(str), vset)
 
         # Parse client key and client certificates
         try:
