@@ -17,7 +17,7 @@
 #
 
 """Base class for reactors waiting on file descriptor I/O events."""
-from __future__ import print_function, unicode_literals
+
 
 from collections import deque
 import copy
@@ -69,7 +69,7 @@ class VFDWaitReactor(threading.Thread):
 
     # Internal message codes for message-driven actions
     (__ADD_READER, __REMOVE_READER, __ADD_WRITER,
-     __REMOVE_WRITER, __STOP, __ADD_CALL, __REMOVE_CALL) = range(7)
+     __REMOVE_WRITER, __STOP, __ADD_CALL, __REMOVE_CALL) = list(range(7))
 
     # Internal codes for internal I/O wait function
     _FD_READ = 1
@@ -592,7 +592,7 @@ class VFDWaitReactor(threading.Thread):
         # infrequently, so a heap is used to optimize for adding and popping
         scheduled_time = call.scheduled_time
         _sc = self.__scheduled_calls
-        for pos in xrange(len(_sc)):
+        for pos in range(len(_sc)):
             if _sc[pos] is call:
                 break
         else:
