@@ -21,7 +21,7 @@
 Importing registers :class:`VContainerModule` as a global module.
 
 """
-from __future__ import print_function, unicode_literals
+
 
 import struct
 
@@ -63,7 +63,7 @@ class VFrozenDict(VERBase, VEntity, VLockable):
         VLockable.__init__(self)
         self.__value = dict()
         lazy = VEntity._v_lazy
-        for key, val in value.items():
+        for key, val in list(value.items()):
             self.__value[lazy(key)] = lazy(val)
 
     def keys(self):
@@ -72,17 +72,17 @@ class VFrozenDict(VERBase, VEntity, VLockable):
 
     def values(self):
         """Similar to :meth:`dict.values`\ ."""
-        return tuple(iter(self.__values.values()))
+        return tuple(iter(list(self.__values.values())))
 
     def items(self):
         """Similar to :meth:`dict.items`\ ."""
-        return tuple((key, val) for key, val in self.__value.items())
+        return tuple((key, val) for key, val in list(self.__value.items()))
 
     def _v_as_tagged(self, context):
         tags = VSECodes.DICTIONARY.tags(context)
         data = []
         with self:
-            for key, value in self.__value.items():
+            for key, value in list(self.__value.items()):
                 data.append(key)
                 data.append(value)
             data = tuple(data)
@@ -352,7 +352,7 @@ class VMultiArray(VLockable):
                     result.append(b'%s: %s' % (tuple(index), fmt(self[index])))
                 else:
                     result.append('%s: %s' % (tuple(index), fmt(self[index])))
-                for i in xrange(len(index)):
+                for i in range(len(index)):
                     index[i] += 1
                     if index[i] < self._dim[i]:
                         break
@@ -479,7 +479,7 @@ class VArrayOfInt(VArrayOf):
         value = tuple(value)
         for _v in value:
             if _pyver == 2:
-                if not isinstance(_v, (int, long)):
+                if not isinstance(_v, int):
                     raise TypeError('All elements must be int')
             else:
                 if not isinstance(_v, int):
@@ -538,7 +538,7 @@ class VArrayOfLong(VArrayOf):
         value = tuple(value)
         for _v in value:
             if _pyver == 2:
-                if not isinstance(_v, (int, long)):
+                if not isinstance(_v, int):
                     raise TypeError('All elements must be int')
             else:
                 if not isinstance(_v, int):
@@ -597,7 +597,7 @@ class VArrayOfVInteger(VArrayOf):
         value = tuple(value)
         for _v in value:
             if _pyver == 2:
-                if not isinstance(_v, (int, long)):
+                if not isinstance(_v, int):
                     raise TypeError('All elements must be int')
             else:
                 if not isinstance(_v, int):
@@ -656,7 +656,7 @@ class VArrayOfFloat(VArrayOf):
         value = tuple(value)
         for _v in value:
             if _pyver == 2:
-                if not isinstance(_v, (float, int, long)):
+                if not isinstance(_v, (float, int)):
                     raise TypeError('All elements must be float convertible')
             else:
                 if not isinstance(_v, (float, int)):
@@ -715,7 +715,7 @@ class VArrayOfDouble(VArrayOf):
         value = tuple(value)
         for _v in value:
             if _pyver == 2:
-                if not isinstance(_v, (float, int, long)):
+                if not isinstance(_v, (float, int)):
                     raise TypeError('All elements must be float convertible')
             else:
                 if not isinstance(_v, (float, int)):
@@ -811,7 +811,7 @@ class VArrayOfVFloat(VArrayOf):
         if len(_nums) % 3 != 0:
             raise VTaggedParseError('Invalid number encoding')
         _vals = []
-        for i in xrange(len(_nums)//3):
+        for i in range(len(_nums)//3):
             _digits = _nums[3*i];
             _base = _nums[3*i + 1];
             _exp = _nums[3*i + 2];
