@@ -17,9 +17,9 @@
 #
 
 """Implements :term:`VSE` native python 2.x and python 3.x objects."""
-from __future__ import print_function, unicode_literals
 
-import Queue
+
+import queue
 import weakref
 
 from versile.internal import _vexport, _pyver
@@ -55,7 +55,7 @@ class VBasePythonObject(VNativeObject):
         self._obj = python_obj
 
     __ext_doc = 'getattribute(attr) - return object attribute'
-    @publish(show=True, doc=__ext_doc)
+    @publish(show=True, doc=__ext_doc, ctx=False)
     def getattribute(self, attr):
         """Retreive an attribute on the object proxied by this class.
 
@@ -78,7 +78,7 @@ class VBasePythonObject(VNativeObject):
         elif attr == '__repr__':
             return _conv(lambda : repr(obj))
         elif attr == '__unicode__':
-            return _conv(lambda : unicode(obj))
+            return _conv(lambda : str(obj))
         elif attr == '__nonzero__':
             return _conv(lambda : bool(obj))
         elif attr == '__getitem__':
@@ -102,7 +102,7 @@ class VBasePythonObject(VNativeObject):
         # General handler
         if isinstance(attr, bytes):
             # Ensure 'attr' is sent as string
-            attr = unicode(attr)
+            attr = str(attr)
         try:
             result = getattr(obj, attr)
         except Exception as e:
@@ -113,7 +113,7 @@ class VBasePythonObject(VNativeObject):
     __ext_doc = ('call(args, kargs) - perform call on (callable) object\n' +
                  '  args  - arguments (tuple)\n' +
                  '  kargs - keyword arguments (VFrozenDict)\n')
-    @publish(show=True, doc=__ext_doc)
+    @publish(show=True, doc=__ext_doc, ctx=False)
     def call(self, args, kargs):
         """Perform a call on the object proxied by this class.
 
@@ -129,14 +129,14 @@ class VBasePythonObject(VNativeObject):
         if not isinstance(kargs, VFrozenDict):
             raise VCallError('Keyword arguments must be a VFrozenDict')
         if kargs:
-            keys, vals = zip(*(kargs.items()))
+            keys, vals = list(zip(*(list(kargs.items()))))
         else:
             keys = vals = tuple()
 
         # Resolve any VPythonObject as native object in the data structures
         args = self._v_obj_from_recv(args)
         keys, vals = self._v_obj_from_recv(keys), self._v_obj_from_recv(vals)
-        kargs = dict(zip(keys, vals))
+        kargs = dict(list(zip(keys, vals)))
 
         # Execute call and convert result/exception
         try:
@@ -294,7 +294,7 @@ class VBasePython(VNative):
         # Package arguments for sending
         _conv = self._v_python_otyp._v_convert_for_send
         c_args = VTuple(_conv(e) for e in args)
-        c_kargs = ((unicode(key), val) for key, val in kargs.items())
+        c_kargs = ((str(key), val) for key, val in list(kargs.items()))
         c_kargs = tuple((_conv(key), _conv(val)) for key, val in c_kargs)
         c_kargs = VFrozenDict(dict(c_kargs))
 
@@ -350,7 +350,7 @@ class VBasePython(VNative):
             return list(_conv(e) for e in iter(result))
         else:
             # Mimic __dir__ behavior
-            return self.__dict__.keys()
+            return list(self.__dict__.keys())
 
     def __iter__(self):
         native_attr = VNative.__getattribute__
@@ -363,7 +363,7 @@ class VBasePython(VNative):
                     self.__it = it
                 def __iter__(self):
                     return self
-                def next(self):
+                def __next__(self):
                     return self.__next__()
                 def __next__(self):
                     result = self.__it._v_exec_and_conv(self.__it.__next__,
@@ -562,11 +562,11 @@ class VBasePythonException(VNativeException):
         'exceptions.OSError': OSError,
         'exceptions.OverflowError': OverflowError,
         'exceptions.PendingDeprecationWarning': PendingDeprecationWarning,
-        'Queue.Empty': Queue.Empty,
+        'Queue.Empty': queue.Empty,
         'exceptions.ReferenceError': ReferenceError,
         'exceptions.RuntimeError': RuntimeError,
         'exceptions.RuntimeWarning': RuntimeWarning,
-        'exceptions.StandardError': StandardError,
+        'exceptions.StandardError': Exception,
         'exceptions.StopIteration': StopIteration,
         'exceptions.SyntaxError': SyntaxError,
         'exceptions.SyntaxWarning': SyntaxWarning,
@@ -587,7 +587,7 @@ class VBasePythonException(VNativeException):
         }
 
     # Conversion table for converting to VPythonException
-    _CONVERSION = dict((val, key) for key, val in _NATIVE_CONVERSION.items())
+    _CONVERSION = dict((val, key) for key, val in list(_NATIVE_CONVERSION.items()))
 
 
 class VPython2Exception(VBasePythonException):
