@@ -21,7 +21,7 @@
 Importing registers :class:`VSemanticModule` as a global module.
 
 """
-from __future__ import print_function, unicode_literals
+
 
 import threading
 
@@ -120,7 +120,7 @@ class VConcept(VERBase, VEntity):
             raise VTaggedParseError('Encoding requires a single residual tag')
         tag = tags[0]
         if _pyver == 2:
-            _itypes = (int, long, VInteger)
+            _itypes = (int, int, VInteger)
         else:
             _itypes = (int, VInteger)
         if not isinstance(tag, _itypes):
@@ -133,7 +133,7 @@ class VConcept(VERBase, VEntity):
                 raise VTaggedParseError('Value must be an 2-tuple')
             for _tmp in _val:
                 if _pyver == 2:
-                    if not isinstance(_tmp, unicode):
+                    if not isinstance(_tmp, str):
                         raise VTaggedParseError('Value element must be string')
                 else:
                     if not isinstance(_tmp, str):
@@ -149,7 +149,7 @@ class VConcept(VERBase, VEntity):
 
         if tag == VConcept.TYPE_EN_WIKIPEDIA:
             if _pyver == 2:
-                if not isinstance(_val, unicode):
+                if not isinstance(_val, str):
                     raise VTaggedParseError('Value must be string')
             else:
                 if not isinstance(_val, str):
@@ -269,7 +269,7 @@ class VPlatformConcept(VConcept):
             if not VPlatformConcept._concepts:
                 # This will initialize concepts and translations
                 VPlatformConcept._translate('')
-            return (key for key in VPlatformConcept._concepts.keys())
+            return (key for key in list(VPlatformConcept._concepts.keys()))
 
 
     def get_equivalent(self, c_type):
@@ -363,7 +363,7 @@ class VEnWikipediaConcept(VConcept):
 
         # Validate appropriate type
         if _pyver == 2:
-            _ftyp, _ttyp = str, unicode
+            _ftyp, _ttyp = str, str
         else:
             _ftyp, _ttyp = bytes, str
         if isinstance(identifier, _ftyp):
@@ -448,7 +448,7 @@ class VUrlConcept(VConcept):
         # Validate appropriate type
         _tmp = []
         if _pyver == 2:
-            _ftyp, _ttyp = str, unicode
+            _ftyp, _ttyp = str, str
         else:
             _ftyp, _ttyp = bytes, str
         for _val in prefix, postfix:
