@@ -21,11 +21,11 @@
 Importing registers :class:`VUtilityModule` as a global module.
 
 """
-from __future__ import print_function, unicode_literals
+
 
 import inspect
 import threading
-import time
+from . import time
 
 from versile.internal import _vexport
 from versile.common.iface import abstract
@@ -112,7 +112,7 @@ class VFunction(VERBase, VExternal):
                     doc = None
                 else:
                     try:
-                        doc = unicode(doc)
+                        doc = str(doc)
                     except:
                         doc = None
                 self._doc = doc
@@ -121,7 +121,7 @@ class VFunction(VERBase, VExternal):
         """Returns *function(\*args)*\ ."""
         return self._func(*args)
 
-    @publish(show=True)
+    @publish(show=True, ctx=False)
     def peer_call(self, *args):
         """Perform function call.
 
@@ -141,7 +141,7 @@ class VFunction(VERBase, VExternal):
 
         return func(*args)
 
-    @publish(show=True)
+    @publish(show=True, ctx=False)
     def peer_doc(self):
         """Return function documentation string.
 
@@ -229,7 +229,7 @@ class VFunctionProxy(VERBase, VEntity):
         for arg in (min_arg, max_arg):
             if arg is None:
                 continue
-            if isinstance(arg, (int, long)) and arg >= 0:
+            if isinstance(arg, int) and arg >= 0:
                 continue
             raise VTaggedParseError('Limit must be non-negative int or None')
         if min_arg is not None and max_arg is not None and max_arg < min_arg:
@@ -373,8 +373,8 @@ class VUDPRelayedVOP(VUDPRelay):
             try:
                 vchk(res, vtyp(tuple), len(res) == 3)
                 host, port, r_token = res
-                vchk(host, vtyp(unicode), vset)
-                vchk(port, vtyp(int, long), 1024<=port<=65535)
+                vchk(host, vtyp(str), vset)
+                vchk(port, vtyp(int, int), 1024<=port<=65535)
                 vchk(r_token, vtyp(bytes), len(r_token)<=32)
             except:
                 conn.peer_gw.cancel()
@@ -510,8 +510,8 @@ class VPasswordLoginHandler(VERBase, VExternal):
     @publish(show=True, ctx=True)
     def login(self, username, password, ctx):
         try:
-            vchk(username, vtyp(unicode))
-            vchk(password, vtyp(unicode))
+            vchk(username, vtyp(str))
+            vchk(password, vtyp(str))
         except:
             self._invalid_type_handler()
         return self.handle_login(username, password, ctx)
